# CoreX logging - elasticsearch

This package provides an implementation of the CoreX logging interface for elasticsearch.

## Installation
~~~bash
pip install corex-logging-elasticsearch
~~~

## Usage
~~~python
from corex_logging_elasticsearch.handler import ElasticsearchHandler
handler = ElasticsearchHandler()
handler.example_method()
~~~

## License
This package is licensed under the MIT License. See [LICENSE](../LICENSE) for details.
